==> libkysdk-applications_2.0.2.1.orig.tar.gz: libkysdk-applications-2.0.2.1/kysdk-qtwidgets/translations/gui_bo_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bo_CN">
<context>
    <name>kdk::KAboutDialog</name>
    <message>
        <location filename="../src/kaboutdialog.cpp" line="97"/>
        <source>No mail applicaiton accessible in your system.</source>
        <translation>ཁྱེད་རང་གི་མ་ལག་ལ་སྦྲག་རྫས་ཉེར་སྤྱོད་གོ་རིམ་གང་ཡང་སྒྲིག་སྦྱོར་བྱས་མེད་།</translation>
    </message>
    <message>
        <location filename="../src/kaboutdialog.cpp" line="98"/>
        <source>Unable to open mail application</source>
        <translation>སྦྲག་རྫས་ཉེར་སྤྱོད་བྱ་རིམ་ཁ་ཕྱེ་མི་ཐུབ་།</translation>
    </message>
    <message>
        <location filename="../src/kaboutdialog.cpp" line="230"/>
        <location filename="../src/kaboutdialog.cpp" line="244"/>
        <source>Service &amp; Support: </source>
        <translation>ཞབས་ཞུ་དང་རྒྱབ་སྐྱོར་ཚོགས་པ་</translation>
    </message>
    <message>
        <location filename="../src/kaboutdialog.cpp" line="236"/>
        <location filename="../src/kaboutdialog.cpp" line="250"/>
        <source>Privacy statement</source>
        <translation>《གསང་བའི་གསལ་བསྒྲགས། 》</translation>
    </message>
</context>
<context>
    <name>kdk::KInputDialog</name>
    <message>
        <location filename="../src/kinputdialog.cpp" line="220"/>
        <source>Enter a value:</source>
        <translation>ཁྱོད་ཀྱིས་གྲངས་ཀ་ནང་འཇུག་གནང་རོགས།</translation>
    </message>
</context>
<context>
    <name>kdk::KInputDialogPrivate</name>
    <message>
        <location filename="../src/kinputdialog.cpp" line="229"/>
        <source>ok</source>
        <translation>དངོས་སུ་ཁས་ལེན་པ།</translation>
    </message>
    <message>
        <location filename="../src/kinputdialog.cpp" line="231"/>
        <source>cancel</source>
        <translation>མེད་པར་བཟོ་དགོས།</translation>
    </message>
</context>
<context>
    <name>kdk::KMenuButton</name>
    <message>
        <source>more</source>
        <translation type="vanished">དེ་བས་ཀྱང་མང་</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="40"/>
        <source>option</source>
        <translation>འདེམས་ཚན་</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="41"/>
        <source>Setting</source>
        <translation>བཀོད་སྒྲིག་བཅས་བྱ་དགོས།</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="42"/>
        <source>Theme</source>
        <translation>ཕྱི་ཚུལ།</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="43"/>
        <source>Assist</source>
        <translation>རོགས་རམ་བྱེད་དགོས།</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="44"/>
        <source>About</source>
        <translation>དེའི་སྐོར།</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="45"/>
        <source>Quit</source>
        <translation>ཕྱིར་འཐེན་བྱ་དགོས།</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="52"/>
        <source>Auto</source>
        <translation>མ་ལག་གི་རྗེས་སུ་འབྲང་བ</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="54"/>
        <source>Light</source>
        <translation>མདོག་སྨུག་པོ།</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="56"/>
        <source>Dark</source>
        <translation>ཚོས་གཞི་ཟབ་པ།</translation>
    </message>
</context>
<context>
    <name>kdk::KProgressDialog</name>
    <message>
        <location filename="../src/kprogressdialog.cpp" line="48"/>
        <source>cancel</source>
        <translation>མེད་པར་བཟོ་དགོས།</translation>
    </message>
</context>
<context>
    <name>kdk::KSearchLineEditPrivate</name>
    <message>
        <location filename="../src/ksearchlineedit.cpp" line="362"/>
        <source>search</source>
        <translation>འཚོལ་ཞིབ་བྱེད་པ།</translation>
    </message>
    <message>
        <location filename="../src/ksearchlineedit.cpp" line="463"/>
        <source>Search</source>
        <translation>འཚོལ་ཞིབ་བྱེད་པ།</translation>
    </message>
</context>
<context>
    <name>kdk::KSecurityLevelBar</name>
    <message>
        <location filename="../src/ksecuritylevelbar.cpp" line="38"/>
        <source>Low</source>
        <translation>དམའ་བ།</translation>
    </message>
    <message>
        <location filename="../src/ksecuritylevelbar.cpp" line="41"/>
        <source>Medium</source>
        <translation>ཀྲུང་གོའི་གུང་ཀྲུང་</translation>
    </message>
    <message>
        <location filename="../src/ksecuritylevelbar.cpp" line="44"/>
        <source>High</source>
        <translation>མཐོན་པོ།</translation>
    </message>
</context>
<context>
    <name>kdk::KSecurityLevelBarPrivate</name>
    <message>
        <location filename="../src/ksecuritylevelbar.cpp" line="112"/>
        <source>Low</source>
        <translation>དམའ་བ།</translation>
    </message>
</context>
<context>
    <name>kdk::KUninstallDialog</name>
    <message>
        <location filename="../src/kuninstalldialog.cpp" line="102"/>
        <location filename="../src/kuninstalldialog.cpp" line="194"/>
        <source>uninstall</source>
        <translation>འཕྲལ་མར་ཕབ་ལེན་བྱེད་དགོས།</translation>
    </message>
    <message>
        <location filename="../src/kuninstalldialog.cpp" line="163"/>
        <source>deb name:</source>
        <translation>འགན་གཙང་ལེན་པའི་མིང་འདི</translation>
    </message>
    <message>
        <location filename="../src/kuninstalldialog.cpp" line="168"/>
        <source>deb version:</source>
        <translation>པར་གཞི།</translation>
    </message>
</context>
<context>
    <name>kdk::KUninstallDialogPrivate</name>
    <message>
        <location filename="../src/kuninstalldialog.cpp" line="283"/>
        <source>deb name:</source>
        <translation>འགན་གཙང་ལེན་པའི་མིང་འདི</translation>
    </message>
    <message>
        <location filename="../src/kuninstalldialog.cpp" line="287"/>
        <source>deb version:</source>
        <translation>པར་གཞི།</translation>
    </message>
</context>
<context>
    <name>kdk::KWindowButtonBarPrivate</name>
    <message>
        <location filename="../src/kwindowbuttonbar.cpp" line="192"/>
        <source>minimize</source>
        <translation>ཆེས་ཆུང་བ་ཡིན།</translation>
    </message>
    <message>
        <location filename="../src/kwindowbuttonbar.cpp" line="246"/>
        <source>maximize</source>
        <translation>ཆེས་ཆེ་བ་བཅས་སུ་འགྱུར་བར་</translation>
    </message>
    <message>
        <location filename="../src/kwindowbuttonbar.cpp" line="251"/>
        <source>restore</source>
        <translation>སླར་གསོ་བྱེད་དགོས།</translation>
    </message>
    <message>
        <location filename="../src/kwindowbuttonbar.cpp" line="201"/>
        <source>close</source>
        <translation>སྒོ་རྒྱག་པ།</translation>
    </message>
</context>
</TS>

==> libkysdk-applications_2.2.1.0.orig.tar.gz: libkysdk-applications-2.2.1.0/kysdk-qtwidgets/translations/gui_bo_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bo_CN">
<context>
    <name>kdk::KAboutDialog</name>
    <message>
        <location filename="../src/kaboutdialog.cpp" line="98"/>
        <source>No mail applicaiton accessible in your system.</source>
        <translation>ཁྱེད་རང་གི་མ་ལག་ལ་སྦྲག་རྫས་ཉེར་སྤྱོད་གོ་རིམ་གང་ཡང་སྒྲིག་སྦྱོར་བྱས་མེད་།</translation>
    </message>
    <message>
        <location filename="../src/kaboutdialog.cpp" line="99"/>
        <source>Unable to open mail application</source>
        <translation>སྦྲག་རྫས་ཉེར་སྤྱོད་བྱ་རིམ་ཁ་ཕྱེ་མི་ཐུབ་།</translation>
    </message>
    <message>
        <location filename="../src/kaboutdialog.cpp" line="231"/>
        <location filename="../src/kaboutdialog.cpp" line="245"/>
        <source>Service &amp; Support: </source>
        <translation>ཞབས་ཞུ་དང་རྒྱབ་སྐྱོར་ཚོགས་པ་</translation>
    </message>
    <message>
        <location filename="../src/kaboutdialog.cpp" line="237"/>
        <location filename="../src/kaboutdialog.cpp" line="251"/>
        <source>Privacy statement</source>
        <translation>《གསང་བའི་གསལ་བསྒྲགས། 》</translation>
    </message>
</context>
<context>
    <name>kdk::KAboutDialogPrivate</name>
    <message>
        <location filename="../src/kaboutdialog.cpp" line="347"/>
        <source>version :</source>
        <translation>པར་གཞི།</translation>
    </message>
    <message>
        <location filename="../src/kaboutdialog.cpp" line="352"/>
        <source>Version number not found</source>
        <translation>པར་གཞིའི་ཨང་གྲངས་རྙེད་མ་བྱུང་།</translation>
    </message>
</context>
<context>
    <name>kdk::KInputDialog</name>
    <message>
        <location filename="../src/kinputdialog.cpp" line="220"/>
        <source>Enter a value:</source>
        <translation>ཁྱོད་ཀྱིས་གྲངས་ཀ་ནང་འཇུག་གནང་རོགས།</translation>
    </message>
</context>
<context>
    <name>kdk::KInputDialogPrivate</name>
    <message>
        <location filename="../src/kinputdialog.cpp" line="229"/>
        <source>ok</source>
        <translation>དངོས་སུ་ཁས་ལེན་པ།</translation>
    </message>
    <message>
        <location filename="../src/kinputdialog.cpp" line="231"/>
        <source>cancel</source>
        <translation>མེད་པར་བཟོ་དགོས།</translation>
    </message>
</context>
<context>
    <name>kdk::KMenuButton</name>
    <message>
        <source>Option</source>
        <translation type="vanished">འདེམས་ཚན་</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="40"/>
        <source>Options</source>
        <translation>འདེམས་ཚན་</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="41"/>
        <source>Setting</source>
        <translation>བཀོད་སྒྲིག་བཅས་བྱ་དགོས།</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="42"/>
        <source>Theme</source>
        <translation>ཕྱི་ཚུལ།</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="43"/>
        <source>Assist</source>
        <translation>རོགས་རམ་བྱེད་དགོས།</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="44"/>
        <source>About</source>
        <translation>དེའི་སྐོར།</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="45"/>
        <source>Quit</source>
        <translation>ཕྱིར་འཐེན་བྱ་དགོས།</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="52"/>
        <source>Auto</source>
        <translation>མ་ལག་གི་རྗེས་སུ་འབྲང་བ</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="54"/>
        <source>Light</source>
        <translation>མདོག་སྨུག་པོ།</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="56"/>
        <source>Dark</source>
        <translation>ཚོས་གཞི་ཟབ་པ།</translation>
    </message>
</context>
<context>
    <name>kdk::KProgressDialog</name>
    <message>
        <location filename="../src/kprogressdialog.cpp" line="48"/>
        <source>cancel</source>
        <translation>མེད་པར་བཟོ་དགོས།</translation>
    </message>
</context>
<context>
    <name>kdk::KSearchLineEditPrivate</name>
    <message>
        <location filename="../src/ksearchlineedit.cpp" line="384"/>
        <source>search</source>
        <translation>འཚོལ་ཞིབ་བྱེད་པ།</translation>
    </message>
    <message>
        <location filename="../src/ksearchlineedit.cpp" line="486"/>
        <source>Search</source>
        <translation>འཚོལ་ཞིབ་བྱེད་པ།</translation>
    </message>
</context>
<context>
    <name>kdk::KSecurityLevelBar</name>
    <message>
        <location filename="../src/ksecuritylevelbar.cpp" line="38"/>
        <source>Low</source>
        <translation>དམའ་བ།</translation>
    </message>
    <message>
        <location filename="../src/ksecuritylevelbar.cpp" line="41"/>
        <source>Medium</source>
        <translation>ཀྲུང་གོའི་གུང་ཀྲུང་</translation>
    </message>
    <message>
        <location filename="../src/ksecuritylevelbar.cpp" line="44"/>
        <source>High</source>
        <translation>མཐོན་པོ།</translation>
    </message>
</context>
<context>
    <name>kdk::KSecurityLevelBarPrivate</name>
    <message>
        <location filename="../src/ksecuritylevelbar.cpp" line="112"/>
        <source>Low</source>
        <translation>དམའ་བ།</translation>
    </message>
</context>
<context>
    <name>kdk::KUninstallDialog</name>
    <message>
        <location filename="../src/kuninstalldialog.cpp" line="102"/>
        <location filename="../src/kuninstalldialog.cpp" line="194"/>
        <source>uninstall</source>
        <translation>འཕྲལ་མར་ཕབ་ལེན་བྱེད་དགོས།</translation>
    </message>
    <message>
        <location filename="../src/kuninstalldialog.cpp" line="163"/>
        <source>deb name:</source>
        <translation>འགན་གཙང་ལེན་པའི་མིང་འདི</translation>
    </message>
    <message>
        <location filename="../src/kuninstalldialog.cpp" line="168"/>
        <source>deb version:</source>
        <translation>པར་གཞི།</translation>
    </message>
</context>
<context>
    <name>kdk::KUninstallDialogPrivate</name>
    <message>
        <location filename="../src/kuninstalldialog.cpp" line="283"/>
        <source>deb name:</source>
        <translation>འགན་གཙང་ལེན་པའི་མིང་འདི</translation>
    </message>
    <message>
        <location filename="../src/kuninstalldialog.cpp" line="287"/>
        <source>deb version:</source>
        <translation>པར་གཞི།</translation>
    </message>
</context>
<context>
    <name>kdk::KWindowButtonBarPrivate</name>
    <message>
        <location filename="../src/kwindowbuttonbar.cpp" line="192"/>
        <source>Minimize</source>
        <translation>ཆེས་ཆུང་ཅན་</translation>
    </message>
    <message>
        <location filename="../src/kwindowbuttonbar.cpp" line="201"/>
        <source>Close</source>
        <translation>སྒོ་རྒྱག་པ་</translation>
    </message>
    <message>
        <location filename="../src/kwindowbuttonbar.cpp" line="250"/>
        <source>Maximize</source>
        <translation>ཆེ་ཤོས་སུ་སྒྱུར་བ་</translation>
    </message>
    <message>
        <location filename="../src/kwindowbuttonbar.cpp" line="255"/>
        <source>Restore</source>
        <translation>སླར་གསོ་བྱེད་དགོས།</translation>
    </message>
</context>
</TS>
